import _defineProperty from '@babel/runtime/helpers/defineProperty';

/**
 * Detector classes obtain list of user's locales. It can be from browser, url, cookies, storage, ... whatever you want
 * Get locales method always return array of locales.
 */
class Detector {}

/**
 * Navigator detector try load locales from browser navigator variable.
 */

class NavigatorDetector extends Detector {
  /**
   * On default languages are loaded from window.navigator
   *
   * @param {Navigator} navigator - browser navigator variable
   */
  constructor(navigator = window.navigator) {
    super();

    _defineProperty(this, "navigator", void 0);

    this.navigator = navigator;
  }
  /**
   * Get list of locales.
   *
   * @returns {Array<string>} list of locales from browser
   */


  getLocales() {
    // @ts-ignore
    const {
      languages,
      language,
      userLanguage
    } = this.navigator;

    if (Array.isArray(languages)) {
      return languages;
    }

    if (language) {
      return [language];
    }

    if (userLanguage) {
      return [userLanguage];
    }

    return [];
  }

}

export default NavigatorDetector;
