import _defineProperty from '@babel/runtime/helpers/defineProperty';

/**
 * Transformer are used to change format of locale (eg. convert it to uppercase), create fallbacks or delete invalid items.
 */
class Transformer {}

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
const defaultConvertTable = {
  'es-XL': 'es-419',
  hindi: 'hi',
  indonesian: 'id',
  english: 'en'
};
/**
 * It convert invalid locales.
 */

class InvalidLocalesTransformer extends Transformer {
  /**
   * Constructor.
   *
   * @param {SimpleObject} convertTable - simple convert table
   */
  constructor(convertTable = {}) {
    super();

    _defineProperty(this, "convertTable", void 0);

    this.convertTable = _objectSpread(_objectSpread({}, defaultConvertTable), convertTable);
  }
  /**
   * Transform invalid languages.
   *
   * @param {Array<string>} locales - list of locales
   * @returns {Array<string>} cleaned list of locales
   */


  transform(locales) {
    return locales.map(locale => {
      return this.convertTable[locale] || locale;
    });
  }

}

export default InvalidLocalesTransformer;
